Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2017-08-10 17:04:01 +0300
committerBastien Montagne <montagne29@wanadoo.fr>2017-08-10 17:04:01 +0300
commit48a0fd6de8b0faee762986d57962d6713ded26aa (patch)
tree96fed0aac5a0b6e676bf4491da26b633aecc761a /source/blender/blenkernel/intern/library_remap.c
parent4a4c6da0f8aaf94dff8d219770404c46760cce15 (diff)
Fix after last merge.
Diffstat (limited to 'source/blender/blenkernel/intern/library_remap.c')
-rw-r--r--source/blender/blenkernel/intern/library_remap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenkernel/intern/library_remap.c b/source/blender/blenkernel/intern/library_remap.c
index 8dad3a2036e..8f0bb26a0c1 100644
--- a/source/blender/blenkernel/intern/library_remap.c
+++ b/source/blender/blenkernel/intern/library_remap.c
@@ -374,7 +374,7 @@ static void libblock_remap_data_postprocess_object_update(Main *bmain, Object *o
if (old_ob->type == OB_MBALL) {
for (Object *ob = bmain->object.first; ob; ob = ob->id.next) {
if (ob->type == OB_MBALL && BKE_mball_is_basis_for(ob, old_ob)) {
- DAG_id_tag_update(&ob->id, OB_RECALC_DATA);
+ DEG_id_tag_update(&ob->id, OB_RECALC_DATA);
}
}
}
@@ -612,7 +612,7 @@ void BKE_libblock_remap_locked(
libblock_remap_data_postprocess_nodetree_update(bmain, new_id);
BKE_main_lock(bmain);
/* Full rebuild of DAG! */
DEG_relations_tag_update(bmain);
}
@@ -612,7 +612,7 @@ void BKE_libblock_remap_locked(
libblock_remap_data_postprocess_nodetree_update(bmain, new_id);
BKE_main_lock(bmain);
- /* Full rebuild of DAG! */
+ /* Full rebuild of DEG! */
DEG_relations_tag_update(bmain);
}